wallaroo.wallaroo_ml_ops_api_client.models.v1_task_get_by_id_response_200 API documentation

# wallaroo.wallaroo_ml_ops_api_client.models.v1_task_get_by_id_response_200

View Source

     1from typing import Any, Dict, List, Type, TypeVar
     2
     3import attr
     4
     5from ..models.v1_task_get_by_id_response_200_task import \
     6    V1TaskGetByIdResponse200Task
     7
     8T = TypeVar("T", bound="V1TaskGetByIdResponse200")
     9
    10@attr.s(auto_attribs=True)
    11class V1TaskGetByIdResponse200:
    12    """ Response body of /tasks/get_by_id
    13
    14    Attributes:
    15        task (V1TaskGetByIdResponse200Task):  The task by it's given id
    16    """
    17
    18    task: V1TaskGetByIdResponse200Task
    19    additional_properties: Dict[str, Any] = attr.ib(init=False, factory=dict)
    20
    21
    22    def to_dict(self) -> Dict[str, Any]:
    23        task = self.task.to_dict()
    24
    25
    26        field_dict: Dict[str, Any] = {}
    27        field_dict.update(self.additional_properties)
    28        field_dict.update({
    29            "task": task,
    30        })
    31
    32        return field_dict
    33
    34
    35
    36    @classmethod
    37    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
    38        d = src_dict.copy()
    39        task = V1TaskGetByIdResponse200Task.from_dict(d.pop("task"))
    40
    41
    42
    43
    44        v1_task_get_by_id_response_200 = cls(
    45            task=task,
    46        )
    47
    48        v1_task_get_by_id_response_200.additional_properties = d
    49        return v1_task_get_by_id_response_200
    50
    51    @property
    52    def additional_keys(self) -> List[str]:
    53        return list(self.additional_properties.keys())
    54
    55    def __getitem__(self, key: str) -> Any:
    56        return self.additional_properties[key]
    57
    58    def __setitem__(self, key: str, value: Any) -> None:
    59        self.additional_properties[key] = value
    60
    61    def __delitem__(self, key: str) -> None:
    62        del self.additional_properties[key]
    63
    64    def __contains__(self, key: str) -> bool:
    65        return key in self.additional_properties

@attr.s(auto_attribs=True)
class V1TaskGetByIdResponse200: View Source

    11@attr.s(auto_attribs=True)
    12class V1TaskGetByIdResponse200:
    13    """ Response body of /tasks/get_by_id
    14
    15    Attributes:
    16        task (V1TaskGetByIdResponse200Task):  The task by it's given id
    17    """
    18
    19    task: V1TaskGetByIdResponse200Task
    20    additional_properties: Dict[str, Any] = attr.ib(init=False, factory=dict)
    21
    22
    23    def to_dict(self) -> Dict[str, Any]:
    24        task = self.task.to_dict()
    25
    26
    27        field_dict: Dict[str, Any] = {}
    28        field_dict.update(self.additional_properties)
    29        field_dict.update({
    30            "task": task,
    31        })
    32
    33        return field_dict
    34
    35
    36
    37    @classmethod
    38    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
    39        d = src_dict.copy()
    40        task = V1TaskGetByIdResponse200Task.from_dict(d.pop("task"))
    41
    42
    43
    44
    45        v1_task_get_by_id_response_200 = cls(
    46            task=task,
    47        )
    48
    49        v1_task_get_by_id_response_200.additional_properties = d
    50        return v1_task_get_by_id_response_200
    51
    52    @property
    53    def additional_keys(self) -> List[str]:
    54        return list(self.additional_properties.keys())
    55
    56    def __getitem__(self, key: str) -> Any:
    57        return self.additional_properties[key]
    58
    59    def __setitem__(self, key: str, value: Any) -> None:
    60        self.additional_properties[key] = value
    61
    62    def __delitem__(self, key: str) -> None:
    63        del self.additional_properties[key]
    64
    65    def __contains__(self, key: str) -> bool:
    66        return key in self.additional_properties

Response body of /tasks/get_by_id

Attributes: task (V1TaskGetByIdResponse200Task): The task by it's given id

V1TaskGetByIdResponse200( task: wallaroo.wallaroo_ml_ops_api_client.models.v1_task_get_by_id_response_200_task.V1TaskGetByIdResponse200Task) View Source

    2def __init__(self, task):
    3    self.task = task
    4    self.additional_properties = __attr_factory_additional_properties()

Method generated by attrs for class V1TaskGetByIdResponse200.

def to_dict(self) -> Dict[str, Any]: View Source

    23    def to_dict(self) -> Dict[str, Any]:
    24        task = self.task.to_dict()
    25
    26
    27        field_dict: Dict[str, Any] = {}
    28        field_dict.update(self.additional_properties)
    29        field_dict.update({
    30            "task": task,
    31        })
    32
    33        return field_dict

@classmethod
def from_dict(cls: Type[~T], src_dict: Dict[str, Any]) -> ~T: View Source

    37    @classmethod
    38    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
    39        d = src_dict.copy()
    40        task = V1TaskGetByIdResponse200Task.from_dict(d.pop("task"))
    41
    42
    43
    44
    45        v1_task_get_by_id_response_200 = cls(
    46            task=task,
    47        )
    48
    49        v1_task_get_by_id_response_200.additional_properties = d
    50        return v1_task_get_by_id_response_200

additional_keys: List[str]